@@ -9,9 +9,15 @@ using namespace Rcpp;
 double kern_gauss(
     const Eigen::VectorXd X_one,
     const Eigen::VectorXd X_two,
-    const double bandwidth
+    const double bandwidth,
+    const bool raw
 ){
   double dist = (X_one - X_two).squaredNorm();
-  double out = std::exp(-dist/bandwidth);
+  double out;
+  if (raw){
+    out = dist;
+  }else{
+    out = std::exp(-dist/bandwidth);
+  }
   return out;
 }
